@@ -19,7 +19,7 @@ from pyconfs.configuration import Configuration  # noqa
 # Version of PyConfs
 #
 # This is automatically set using the bumpversion tool
-__version__ = "0.5.0"
+__version__ = "0.5.2"
 
 
 # Homepage for PyConfs
@@ -32,8 +32,8 @@ _AUTHORS = [
     _Author("Geir Arne Hjelle", "geirarne@gmail.com", _date(2019, 4, 1), _date.max)
 ]
 
-__author__ = ", ".join(a.name for a in _AUTHORS if a.start < _date.today() < a.end)
-__contact__ = ", ".join(a.email for a in _AUTHORS if a.start < _date.today() < a.end)
+__author__ = ", ".join(a.name for a in _AUTHORS if a.start <= _date.today() <= a.end)
+__contact__ = ", ".join(a.email for a in _AUTHORS if a.start <= _date.today() <= a.end)
 
 
 # Update doc with info about maintainers
@@ -48,7 +48,7 @@ def _update_doc(doc: str) -> str:
     """
     # Maintainers
     maintainer_list = [
-        f"+ {a.name} <{a.email}>" for a in _AUTHORS if a.start < _date.today() < a.end
+        f"+ {a.name} <{a.email}>" for a in _AUTHORS if a.start <= _date.today() <= a.end
     ]
     maintainers = "\n".join(maintainer_list)
 
